summaryrefslogtreecommitdiffstats
path: root/lib/qextfileinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/qextfileinfo.h')
-rw-r--r--lib/qextfileinfo.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/qextfileinfo.h b/lib/qextfileinfo.h
index ca51123b..6a9e52c7 100644
--- a/lib/qextfileinfo.h
+++ b/lib/qextfileinfo.h
@@ -22,13 +22,13 @@
#include <tqdict.h>
#include <tqregexp.h>
-class TQExtFileInfo:public TQObject
+class QExtFileInfo:public TQObject
{
Q_OBJECT
TQ_OBJECT
public:
- TQExtFileInfo() {};
- ~TQExtFileInfo() {};
+ QExtFileInfo() {};
+ ~QExtFileInfo() {};
/**
* Works like TQDir::canonicalPath, but it does not return an empty
@@ -38,7 +38,7 @@ public:
* Example:
* /home/user/foo points to /mnt/foo
* /home/user/foo/foo2 does not exists
* TQExtFileInfo::canonicalPath("/home/user/foo/foo2/") will return
* /mnt/foo/foo2/ .
* @param path the path to resolve
* @return the canonical path (symlinks resolved)
@@ -38,7 +38,7 @@ public:
* /home/user/foo points to /mnt/foo
* /home/user/foo/foo2 does not exists
- * TQExtFileInfo::canonicalPath("/home/user/foo/foo2/") will return
+ * QExtFileInfo::canonicalPath("/home/user/foo/foo2/") will return
* /mnt/foo/foo2/ .
* @param path the path to resolve